package org.nakedobjects.nos.store.file;

import org.nakedobjects.noa.persist.ObjectNotFoundException;
import org.nakedobjects.noa.persist.ObjectPersistenceException;
import org.nakedobjects.nof.core.persist.SerialOid;


public interface DataManager {
    SerialOid createOid() throws PersistorException;

    void getNakedClass(String name);

    /**
     * Save the data for an object and adds the reference to a list of instances
     */
    void insertObject(ObjectData data);

    /**
     * Loads in data for a collection for the specified identifier.
     */
    CollectionData loadCollectionData(SerialOid oid);

    /**
     * Loads in data for an object for the specified identifier.
     */
    ObjectData loadObjectData(SerialOid oid);

    void remove(SerialOid oid) throws ObjectNotFoundException, ObjectPersistenceException;

    /**
     * Save the data for latter retrieval.
     */
    void save(Data data);

    void shutdown();

    /**
     * Return data for all instances that match the pattern.
     */
    public ObjectDataVector getInstances(final ObjectData pattern);

    public Data loadData(final SerialOid oid);

    /**
     * Return the number of instances that match the specified data
     */
    public int numberOfInstances(final ObjectData pattern);

    String getDebugData();

    boolean isInitialized();
}
// Copyright (c) Naked Objects Group Ltd.
