package org.nakedobjects.nos.store.file;

import java.io.Serializable;
import java.util.Date;

import org.nakedobjects.noa.adapter.Version;
import org.nakedobjects.noa.util.ByteDecoder;
import org.nakedobjects.noa.util.ByteEncoder;
import org.nakedobjects.noa.util.Encodable;
import org.nakedobjects.nof.core.adapter.AbstractVersion;
import org.nakedobjects.nof.core.util.NotImplementedException;
import org.nakedobjects.nof.core.util.ToString;


class FileVersion extends AbstractVersion implements Encodable, Serializable{
    private static final long serialVersionUID = 1L;
    private static Clock clock;

    public static void setClock(final Clock clock) {
        FileVersion.clock = clock;
    }

    public FileVersion(final String user) {
        this(user, clock.getTime());
    }

    public FileVersion(final String user, final long sequence) {
        super(user, new Date(sequence));
    }

    public FileVersion(ByteDecoder decoder) {
        super(decoder.getString(), new Date(decoder.getLong()));
    }
    
    public void encode(ByteEncoder encoder) {
        encoder.add(user);
        encoder.add(time.getTime());
    }
    
    protected AbstractVersion next() {
        // return new FileVersion(user);
        throw new NotImplementedException();
    }

    public boolean different(final Version version) {
        if (version instanceof FileVersion) {
            FileVersion other = (FileVersion) version;
            return !sameTime(other);
        } else {
            return false;
        }
    }

    private boolean sameTime(final FileVersion other) {
        return time.getTime() == other.time.getTime();
    }

    public boolean equals(final Object obj) {
        if (obj == this) {
            return true;
        } else if (obj instanceof FileVersion) {
            return sameTime((FileVersion) obj);
        } else {
            return false;
        }
    }

    long getSequence() {
        return time.getTime();
    }
    
    public String sequence() {
        return Long.toString(getSequence(), 16);
    }

    public String toString() {
        ToString str = new ToString(this);
        str.append("sequence", time.getTime());
        str.append("time", time);
        str.append("user", user);
        return str.toString();
    }
}
// Copyright (c) Naked Objects Group Ltd.
