package org.nakedobjects.nos.store.file.utility;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import org.nakedobjects.noa.NakedObjectRuntimeException;


public class CopyXmlObjectStore {
    public static void main(final String[] args) {
        String workingDirectory = args[0];
        String testDirectory = args[1];

        copyAllFiles(testDirectory, workingDirectory);
    }

    private static void copyAllFiles(final String testDirectory, final String workingDirectory) {
        File from = new File(testDirectory);
        File to = new File(workingDirectory);

        if (!to.exists()) {
            to.mkdirs();
        }
        if (to.isFile()) {
            throw new NakedObjectRuntimeException("To directory is actually a file " + to.getAbsolutePath());
        }

        String list[] = from.list();
        for (int i = 0; i < list.length; i++) {
            copyFile(new File(from, list[i]), new File(to, list[i]));
        }
    }

    private static void copyFile(final File from, final File to) {
        BufferedInputStream bis = null;
        BufferedOutputStream bos = null;
        try {
            bis = new BufferedInputStream(new FileInputStream(from));
            bos = new BufferedOutputStream(new FileOutputStream(to));

            byte buffer[] = new byte[2048];

            int len = 0;
            while ((len = bis.read(buffer)) > 0) {
                bos.write(buffer, 0, len);
            }
        } catch (IOException e) {
            throw new NakedObjectRuntimeException("Error copying file " + from.getAbsolutePath() + " to " + to.getAbsolutePath(),
                    e);
        } finally {
            if (bis != null) {
                try {
                    bis.close();
                } catch (IOException ignore) {}
            }
            if (bos != null) {
                try {
                    bos.close();
                } catch (IOException ignore) {}
            }
        }
    }

}
// Copyright (c) Naked Objects Group Ltd.
